==> xlniuxdata-coin-1.0.2-20160516.104350-1-sources.jar: com/xunlei/niux/data/coin/bo/BaseSoImpl.java <==
package com.xunlei.niux.data.coin.bo;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.ferret.common.dao.BaseDao;
import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.vo.Page;

@Service
public class BaseSoImpl implements BaseSo{
	@Resource(name="BaseDao")
	private BaseDao baseDao;
	
	public BaseDao getBaseDao() {
		return baseDao;
	}

	public void setBaseDao(BaseDao baseDao) {
		this.baseDao = baseDao;
	}
	public <T> T findById(Class<T> clazz,Number id){
		return baseDao.findById(clazz,id);
	}
	public <T> T findById(Class<T> clazz,String id){
		return baseDao.findById(clazz, id);
	}
	public <T> T findObject(T queryObject){
		Page page=new Page();
		List<T> list= findObjects(queryObject,page);
		return (list==null||list.size()==0)?null:list.get(0);
	}
	@SuppressWarnings("unchecked")
	public <T> List<T> findObjects(T queryObject,Page page){
		return (List<T>) baseDao.findByObject(queryObject.getClass(),queryObject,page);
	}
	public <T> void addObject(T object){
		baseDao.insert(object);
	}
	public <T> void deleteById(Class<T> clazz,Number id){
		baseDao.deleteById(clazz, id);
	}
	public <T> void deleteById(Class<T> clazz,String id){
		baseDao.deleteById(clazz, id);
	}
	public <T> void updateObjectById(T object){
		baseDao.updateById(object);
	}
	public <T> int countObject(T object){
		return baseDao.count(object);
	}
	public List executeQuery(Class class1, String sql, List list) {       
		return baseDao.executeQuery(class1, sql, list);
	}
}

==> xlniuxdata-coin-1.0.11-sources.jar: com/xunlei/niux/data/coin/bo/BaseSoImpl.java <==
package com.xunlei.niux.data.coin.bo;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.ferret.common.dao.BaseDao;
import com.ferret.common.dao.BaseDaoImpl;
import com.ferret.common.dao.vo.Page;

@Service
public class BaseSoImpl implements BaseSo{
	@Resource(name="BaseDao")
	private BaseDao baseDao;
	
	public BaseDao getBaseDao() {
		return baseDao;
	}

	public void setBaseDao(BaseDao baseDao) {
		this.baseDao = baseDao;
	}
	public <T> T findById(Class<T> clazz,Number id){
		return baseDao.findById(clazz,id);
	}
	public <T> T findById(Class<T> clazz,String id){
		return baseDao.findById(clazz, id);
	}
	public <T> T findObject(T queryObject){
		Page page=new Page();
		List<T> list= findObjects(queryObject,page);
		return (list==null||list.size()==0)?null:list.get(0);
	}
	@SuppressWarnings("unchecked")
	public <T> List<T> findObjects(T queryObject,Page page){
		return (List<T>) baseDao.findByObject(queryObject.getClass(),queryObject,page);
	}
	public <T> void addObject(T object){
		baseDao.insert(object);
	}
	public <T> void deleteById(Class<T> clazz,Number id){
		baseDao.deleteById(clazz, id);
	}
	public <T> void deleteById(Class<T> clazz,String id){
		baseDao.deleteById(clazz, id);
	}
	public <T> void updateObjectById(T object){
		baseDao.updateById(object);
	}
	public <T> int countObject(T object){
		return baseDao.count(object);
	}
	public List executeQuery(Class class1, String sql, List list) {       
		return baseDao.executeQuery(class1, sql, list);
	}
	public int count(String sql,Object [] args){
	    return ((com.ferret.common.dao.BaseDaoImpl)baseDao).getJdbcTemplate().queryForInt(sql, args);
	}
}
